@@ -1,9 +1,12 @@
 """Provide a model for the Z-Wave JS node."""
+from enum import IntEnum
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, TypedDict, Union, cast
+
 from zwave_js_server.const import CommandClass
 
-from ..exceptions import UnparseableValue, UnwriteableValue
 from ..event import Event, EventBase
+from ..exceptions import UnparseableValue, UnwriteableValue
+from .command_class import CommandClassInfo, CommandClassInfoDataType
 from .device_class import DeviceClass, DeviceClassDataType
 from .device_config import DeviceConfig, DeviceConfigDataType
 from .endpoint import Endpoint, EndpointDataType
@@ -22,6 +25,19 @@ if TYPE_CHECKING:
     from ..client import Client
 
 
+class NodeStatus(IntEnum):
+    """Enum with all Node status values.
+
+    https://zwave-js.github.io/node-zwave-js/#/api/node?id=status
+    """
+
+    UNKNOWN = 0
+    ASLEEP = 1
+    AWAKE = 2
+    DEAD = 3
+    ALIVE = 4
+
+
 class NodeDataType(TypedDict, total=False):
     """Represent a node data dict type."""
 
@@ -58,6 +74,8 @@ class NodeDataType(TypedDict, total=False):
     individualEndpointCount: int
     aggregatedEndpointCount: int
     interviewAttempts: int
+    interviewStage: int
+    commandClasses: List[CommandClassInfoDataType]
     values: List[ValueDataType]
 
 
@@ -85,6 +103,18 @@ class Node(EventBase):
         """Return the representation."""
         return f"{type(self).__name__}(node_id={self.node_id})"
 
+    def __hash__(self) -> int:
+        """Return the hash."""
+        return hash((self.client.driver, self.node_id))
+
+    def __eq__(self, other: object) -> bool:
+        """Return whether this instance equals another."""
+        if not isinstance(other, Node):
+            return False
+        return (
+            self.client.driver == other.client.driver and self.node_id == other.node_id
+        )
+
     @property
     def node_id(self) -> int:
         """Return the node_id."""
@@ -106,9 +136,9 @@ class Node(EventBase):
         return self.data.get("userIcon")
 
     @property
-    def status(self) -> int:
+    def status(self) -> NodeStatus:
         """Return the status."""
-        return self.data["status"]
+        return NodeStatus(self.data["status"])
 
     @property
     def ready(self) -> Optional[bool]:
@@ -118,7 +148,7 @@ class Node(EventBase):
     @property
     def device_class(self) -> DeviceClass:
         """Return the device_class."""
-        return DeviceClass(self.data.get("deviceClass", {}))
+        return DeviceClass(self.data["deviceClass"])
 
     @property
     def is_listening(self) -> Optional[bool]:
@@ -245,6 +275,16 @@ class Node(EventBase):
         """Return the interview_attempts."""
         return self.data.get("interviewAttempts")
 
+    @property
+    def interview_stage(self) -> Optional[int]:
+        """Return the interview_stage."""
+        return self.data.get("interviewStage")
+
+    @property
+    def command_classes(self) -> List[CommandClassInfo]:
+        """Return all CommandClasses supported on this node."""
+        return [CommandClassInfo(cc) for cc in self.data["commandClasses"]]
+
     def get_command_class_values(
         self, command_class: CommandClass, endpoint: int = None
     ) -> Dict[str, Union[ConfigurationValue, Value]]:
@@ -270,7 +310,9 @@ class Node(EventBase):
 
         self.emit(event.type, event.data)
 
-    async def async_set_value(self, val: Union[Value, str], new_value: Any) -> bool:
+    async def async_set_value(
+        self, val: Union[Value, str], new_value: Any, wait_for_result: bool = False
+    ) -> Optional[bool]:
         """Send setValue command to Node for given value (or value_id)."""
         # a value may be specified as value_id or the value itself
         if not isinstance(val, Value):
@@ -280,19 +322,21 @@ class Node(EventBase):
             raise UnwriteableValue
 
         # the value object needs to be send to the server
-        result = await self.client.async_send_command(
-            {
-                "command": "node.set_value",
-                "nodeId": self.node_id,
-                "valueId": val.data,
-                "value": new_value,
-            }
-        )
-        return cast(bool, result["success"])
+        args = {
+            "command": "node.set_value",
+            "nodeId": self.node_id,
+            "valueId": val.data,
+            "value": new_value,
+        }
+        if wait_for_result:
+            result = await self.client.async_send_command(args)
+            return cast(bool, result)
+        await self.client.async_send_command_no_wait(args)
+        return None
 
     async def async_refresh_info(self) -> None:
         """Send refreshInfo command to Node."""
-        await self.client.async_send_command(
+        await self.client.async_send_command_no_wait(
             {
                 "command": "node.refresh_info",
                 "nodeId": self.node_id,
@@ -328,36 +372,43 @@ class Node(EventBase):
 
     async def async_abort_firmware_update(self) -> None:
         """Send abortFirmwareUpdate command to Node."""
-        await self.client.async_send_command(
+        await self.client.async_send_command_no_wait(
             {
                 "command": "node.abort_firmware_update",
                 "nodeId": self.node_id,
             }
         )
 
-    async def async_poll_value(self, val: Union[Value, str]) -> Any:
+    async def async_poll_value(self, val: Union[Value, str]) -> None:
         """Send pollValue command to Node for given value (or value_id)."""
         # a value may be specified as value_id or the value itself
         if not isinstance(val, Value):
             val = self.values[val]
         # the value object needs to be send to the server
-        result = await self.client.async_send_command(
-            {"command": "node.poll_value", "nodeId": self.node_id, "valueId": val.data}
+        await self.client.async_send_command_no_wait(
+            {"command": "node.poll_value", "nodeId": self.node_id, "valueId": val.data},
+            require_schema=1,
         )
-        # result may or may not be there
-        return result.get("result")
 
     def handle_wake_up(self, event: Event) -> None:
         """Process a node wake up event."""
+        # pylint: disable=unused-argument
+        self.data["status"] = NodeStatus.AWAKE
 
     def handle_sleep(self, event: Event) -> None:
         """Process a node sleep event."""
+        # pylint: disable=unused-argument
+        self.data["status"] = NodeStatus.ASLEEP
 
     def handle_dead(self, event: Event) -> None:
         """Process a node dead event."""
+        # pylint: disable=unused-argument
+        self.data["status"] = NodeStatus.DEAD
 
     def handle_alive(self, event: Event) -> None:
         """Process a node alive event."""
+        # pylint: disable=unused-argument
+        self.data["status"] = NodeStatus.ALIVE
 
     def handle_interview_completed(self, event: Event) -> None:
         """Process a node interview completed event."""
